learning_go_task

package module
v2.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 19, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package learning_go_task provides basic math utilities.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Add

func Add[T Number](a T, b T) T

Add takes two Number values and returns their sum. For more information on addition, see: https://www.mathsisfun.com/numbers/addition.html

Types

type Number

type Number interface {
	constraints.Integer | constraints.Float
}

Number is an interface that combines Integer and Float types.

Jump to